@@ -9,12 +9,12 @@
 # The first 20 terms of the series are:
 # 1 1 2 3 3 4 5 5 6 6 6 8 8 8 10 9 10 11 11 12 
 
-# See Hofstadter's book, "Goedel, Escher, Bach: An Eternal Golden Braid",
-# p. 137, ff.
+#  See Hofstadter's book, "Goedel, Escher, Bach: An Eternal Golden Braid",
+#+ p. 137, ff.
 
 
-LIMIT=100     # Number of terms to calculate
-LINEWIDTH=20  # Number of terms printed per line
+LIMIT=100     # Number of terms to calculate.
+LINEWIDTH=20  # Number of terms printed per line.
 
 Q[1]=1        # First two terms of series are 1.
 Q[2]=1
@@ -26,8 +26,8 @@ echo -n "${Q[2]} "
 
 for ((n=3; n <= $LIMIT; n++))  # C-like loop conditions.
 do   # Q[n] = Q[n - Q[n-1]] + Q[n - Q[n-2]]  for n&gt;2
-# Need to break the expression into intermediate terms,
-# since Bash doesn't handle complex array arithmetic very well.
+#  Need to break the expression into intermediate terms,
+#+ since Bash doesn't handle complex array arithmetic very well.
 
   let "n1 = $n - 1"        # n-1
   let "n2 = $n - 2"        # n-2
@@ -42,7 +42,7 @@ Q[n]=`expr $T0 + $T1`      # Q[n - Q[n-1]] + Q[n - Q[n-2]]
 echo -n "${Q[n]} "
 
 if [ `expr $n % $LINEWIDTH` -eq 0 ]    # Format output.
-then   #     mod
+then   #      ^ Modula operator
   echo # Break lines into neat chunks.
 fi
 
@@ -54,4 +54,4 @@ exit 0
 
 # This is an iterative implementation of the Q-series.
 # The more intuitive recursive implementation is left as an exercise.
-# Warning: calculating this series recursively takes a *very* long time.
+# Warning: calculating this series recursively takes a VERY long time.
